tslumd
======

Client and Server for TSLUMD Tally Protocols


Links
=====

.. list-table::

    * - Project Home
      - https://github.com/nocarryr/tslumd
    * - Documentation
      - https://tslumd.readthedocs.io
    * - PyPI
      - https://pypi.org/project/tslumd


License
=======

Copyright (c) 2021 Matthew Reid <matt@nomadic-recording.com>

tslumd is licensed under the MIT license, please see LICENSE file for details.
